@@ -51,13 +51,7 @@ export class PlaceStore extends Gtk.ListStore {
         LANGUAGE: 5
     }
 
-    constructor(params) {
-        let recentPlacesLimit = params.recentPlacesLimit;
-        delete params.recentPlacesLimit;
-
-        let recentRoutesLimit = params.recentRoutesLimit;
-        delete params.recentRoutesLimit;
-
+    constructor({recentPlacesLimit, recentRoutesLimit, ...params}) {
         super(params);
 
         this._recentPlacesLimit = recentPlacesLimit;
@@ -347,6 +341,25 @@ export class PlaceStore extends Gtk.ListStore {
             }
         });
     }
+
+    getCompletedPlaces(places) {
+        let completedPlaces = [];
+
+        places.forEach((place) => {
+            let type;
+
+            if (this.exists(place, PlaceStore.PlaceType.RECENT))
+                type = PlaceStore.PlaceType.RECENT;
+            else if (this.exists(place, PlaceStore.PlaceType.FAVORITE))
+                type = PlaceStore.PlaceType.FAVORITE;
+            else
+                type = PlaceStore.PlaceType.ANY;
+
+            completedPlaces.push({ place: place, type: type });
+        });
+
+        return completedPlaces;
+    }
 }
 
 GObject.registerClass(PlaceStore);
